@@ -10,10 +10,14 @@ from urllib.parse import urlsplit
 
 from django.conf import settings
 from django.contrib.auth import get_user_model
-from django.core.exceptions import FieldDoesNotExist, ImproperlyConfigured
+from django.core.exceptions import (
+    FieldDoesNotExist,
+    ImproperlyConfigured,
+    ValidationError,
+)
 from django.core.files.base import ContentFile
 from django.core.serializers.json import DjangoJSONEncoder
-from django.core.validators import ValidationError, validate_email
+from django.core.validators import validate_email
 from django.db.models import FileField
 from django.db.models.fields import (
     BinaryField,
@@ -81,7 +85,7 @@ def get_username_max_length():
 def generate_username_candidate(basename, suffix_length):
     max_length = get_username_max_length()
     suffix = "".join(
-        random.choice(USERNAME_SUFFIX_CHARS[i]) for i in range(suffix_length)
+        random.choice(USERNAME_SUFFIX_CHARS[i]) for i in range(suffix_length)  # nosec
     )
     return basename[0 : max_length - len(suffix)] + suffix
 
@@ -136,14 +140,14 @@ def valid_email_or_none(email):
 
 
 def import_attribute(path):
-    assert isinstance(path, str)
+    assert isinstance(path, str)  # nosec
     pkg, attr = path.rsplit(".", 1)
     ret = getattr(importlib.import_module(pkg), attr)
     return ret
 
 
 def import_callable(path_or_callable):
-    if not hasattr(path_or_callable, "__call__"):
+    if not callable(path_or_callable):
         ret = import_attribute(path_or_callable)
     else:
         ret = path_or_callable
@@ -168,7 +172,8 @@ def serialize_instance(instance):
         try:
             field = instance._meta.get_field(k)
             if isinstance(field, BinaryField):
-                v = force_str(base64.b64encode(v))
+                if v is not None:
+                    v = force_str(base64.b64encode(v))
             elif isinstance(field, FileField):
                 if v and not isinstance(v, str):
                     v = {
